<?php
/* SEFIP.
 * @package Logic
 * @author  alessandrobartels
 */
class SEFIP
{

    CONST ALFANUMERICOS = '/[^a-zA-Z0-9]/';
    CONST ESTRUTURALEGAL = 'ESTRUTURALEGAL';
    CONST ESTRUTURAGERENCIAL = 'ESTRUTURAGERENCIAL';

    CONST TRANSFERENCIA_ENTRADA = 8;
    CONST TRANSFERENCIA_SAIDA = 9;

    private $_nrOrg;
    private $_nrOrgPadrao;
    private $_mesCompetencia;
    private $_dtInicio;
    private $_dtFim;
    private $_dtAux;
    private $_movimentacao;
    private $_estruturacao;
    private $_tpMovTransfM;
    private $_hierarquiaOrg;
    private $_nrCategoriaTrabalhador;
    private $_registro;
    private $_registro10;
    private $_registro12;
    private $_registro20;
    private $_registro30;
    private $_registro32;
    private $_gfipMagnetico;
    private $_gfipMagneticoTrab;
    private $_dadoAlterado = array(array());
    private $_dadoVinculo = array();
    private $_vrSalarioFamilia;
    private $_vrSalarioMaternidade;
    private $_nrInscricao;
    private $_nrInscricaoTomador;
    private $_nrTpInscricao;
    private $_nrTpInscricaoTomador;
    private $_codMovimentacao;
    private $_pessoa;
    private $_sitFuncional;
    private $_vinculoEmpreg;
    private $_ocupacao;
    private $_cbo;
    private $_altSitFuncional;
    private $_alteracaoSalario;
    private $_tpDemissao;
    private $_listaCalculoFolha;
    private $_itemCalculo;
    private $_assocEvento;
    private $_evento;
    private $_itemGrupo;
    private $_nrPessoaResp;
    private $_vinculom;

    /* Construtor.
     * @param integer             $nrOrg          Numero da Organizacao.
     * @param integer             $nrOrgPadrao    Numero da Organizacao Padrao.
     * @param TkDateTime          $mesCompetencia Mes de competencia.
     * @param FpagfipmagnetEntity $gfipMagnetico  Instancia de FpagfipmagnetEntity.
     * @param string              $nrRecolhimento Numero de recolhimento da GFIP.
     * @param boolean             $competencia13  Identificador de geracao da competencia 13.
     * @author alessandrobartels
     */

    public function __construct($nrOrg, $nrOrgPadrao, TkDateTime $mesCompetencia, FpagfipmagnetEntity $gfipMagnetico,
                                $formulario, $competencia13, $itensGrupo, $listaNrCalculoFolha)
    {

        $this->_nrOrg = $nrOrg;
        $this->_nrOrgPadrao = $nrOrgPadrao;
        $this->_mesCompetencia = $mesCompetencia;
        $this->_dtInicio = new TkDateTime($this->_mesCompetencia);
        $this->_dtFim = new TkDateTime($this->_mesCompetencia);
        $this->_dtFim->addMonth(1)->subDay(1);
        $this->_dtAux = new TkDateTime();
        $this->_pessoa = new GpepessoaEntity(null, $this->_nrOrg, $this->_mesCompetencia);
        $this->_sitFuncional = new GpesitufuncmEntity();
        $this->_vinculoEmpreg = new GpevinculoempregEntity();
        $this->_ocupacao = new GpeOcupacaomEntity(null, $this->_nrOrg, $this->_mesCompetencia);
        $this->_cbo = new GpeCboEntity();
        $this->_altSitFuncional = new GpealtesitufuncEntity(null, $this->_nrOrgPadrao, $this->_nrOrg);
        $this->_alteracaoSalario = new GpealtesalarioEntity(null, $this->_nrOrg);
        $this->_tpDemissao = new FpaTpdemissaoEntity(null, $this->_nrOrgPadrao, $this->_nrOrg);
        $this->_tpMovTransfM = new GpetpmovtransfmEntity(null, $this->_nrOrgPadrao, $this->_nrOrg, $this->_mesCompetencia);
        $this->_listaCalculoFolha = $listaNrCalculoFolha;
        $this->_itemCalculo = new FpaitecalcfolhaEntity();
        $this->_assocEvento = new FpaassoceventoEntity(null, $this->_nrOrg);
        $this->_evento = new FpaeventomEntity(null, $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia);
        $this->_itemGrupo = $itensGrupo;
        $this->_hierarquiaOrg = new HierarquiaorgEntity();
        $this->_estruturacao = new Estruturacao($this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia);
        $this->_gfipMagnetico = $gfipMagnetico;
        $this->_gfipMagneticoTrab = new FpagfipmagnetEntity();
        $this->_registro10 = new Registro10SEFIP();
        $this->_registro12 = new Registro12SEFIP();
        $this->_registro20 = new Registro20SEFIP();
        $this->_registro30 = new Registro30SEFIP();
        $this->_registro32 = new Registro32SEFIP();
        $this->_vinculom = new GpevinculomEntity();
        $this->_inicializaVariaveis($formulario, $competencia13);

    }


    private function _inicializaVariaveis($formulario, $competencia13)
    {

        try {
			// LEONARDOCARVALHO - 28/08/2014
            if ($formulario->getNrhierarqorg() !== '') {
                $this->_estruturacao->carregaHierarquias($formulario->getNrhierarqorg());
            } else {
                throw new \Exception("Favor Informar a Hierarquia.");
            }
        } catch(\Exception $e) {
            throw new \Exception("Hierarquia da Organização: ".$e->getMessage());
        }
        try {
            $this->_estruturacao->carregaHierarquiasTomador($formulario->getNrhierartomador());
        } catch(\Exception $e) {
            throw new \Exception("Hierarquia do Tomador: ".$e->getMessage());
        }
        $this->_estruturacao->carregaTipoHierarquia($formulario->getNrhierarqorg());
        $this->_estruturacao->carregaTipoHierarquiaTomador($formulario->getNrhierartomador());
        $this->_registro10->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro10->setCodCentralizadorFGTS($formulario->getIdcentralfgts());
        $this->_registro10->setCNPJCentralizador($formulario->getNrinsccentraliz());
        $this->_registro10->setCodPagtoGPS($formulario->getCodpagtogps());
        $this->_registro12->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro12->setIdRecolhimentoGPS($formulario->getIdrecolhgps());
        $this->_registro12->setCompetencia($this->_mesCompetencia);
        $this->_registro12->setCompetencia13($competencia13);
        $this->_registro20->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro20->setCodPagtoGPS($formulario->getCodpagtogps());
        $this->_registro30->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro30->setCompetencia($this->_mesCompetencia);
        $this->_registro30->setCompetencia13($competencia13);
        $this->_registro32->setCodigoRecolhimento($formulario->getNrrecolhimento());
        $this->_registro32->setCompetencia($this->_mesCompetencia);
        $this->_registro32->setCompetencia13($competencia13);
        $this->_nrPessoaResp = $formulario->getNrpessoarespons();
    }

    /* Cria os registros SEFIP e armazena na base (10,12,13,14,20,21,30,32,50,51).
     * @param GpevinculomEntity    $vinculo           Instancia de GpevinculomEntity.
     * @param TipohierarqorgEntity $tipoHierarquia    Instancia de TipohierarqorgEntity.
     * @param string               $tpInscHierarq     Tipo de Inscricao da Hierarquia.
     * @param array                $hierarquias       Lista de hierarquias.
     * @param TipohierarqorgEntity $tipoHierarquiaTom Instancia de TipohierarqorgEntity (tomador).
     * @param string               $tpInscHierarqTom  Tipo de Inscricao da Hierarquia (tomador).
     * @param array                $hierarquiasTom    Lista de hierarquias (tomador).
     * @return void
     * @author alessandrobartels
     */

    public function geraSEFIP($vinculo, $nrTipoHierarquiaOrg, $nrTipoHierarquiaTomador, $tpInscHierarq, $tpInscHierarqTom)
    {
        // Carrega os itens de calculo do ultimos 85 meses
        $this->_calculaBasesSEFIP($vinculo->getNrvinculom());
        $this->_vinculo = $vinculo;
        $this->_dtRescisao = $this->_vinculo->getDtrescisaovinc();

//        $estruturaResp = $this->_estruturacao->getEstruturas($vinculo->getNrvinculom(), $nrTipoHierarquiaOrg);
        $ultimoDiaCompetencia = new TkDateTime($this->_mesCompetencia);
        $ultimoDiaCompetencia->addMonth(1)->subDay(1);

        // $estruturaResp = Gpemovimentacao::getMovimentacao($this->_nrOrg, \FPA::getTipoEstruturaLegalOrg(), $vinculo->getNrvinculom());
        $estruturaResp = Gpemovimentacao::getMovimentacoes($this->_nrOrg, \FPA::getTipoEstruturaLegalOrg(), $vinculo->getNrvinculom());
        if ($estruturaResp) {
            // LEONARDOCARVALHO - 03/10/2014 - PERCORRE TODAS AS MOVIMENTAÇÕES
            foreach ($estruturaResp as $estrutura) {

                // LEONARDOCARVALHO - 23/02/2015 - PRIORIZA O NÚMERO DO CEI, CASO NÃO POSSUA SETA O NUMERO DO CNPJ
                $nrCei  = preg_replace(self::ALFANUMERICOS, '', $estrutura->getEstrutura()->getHistorico()->getCdceiestrut());
                $nrCnpj = preg_replace(self::ALFANUMERICOS, '', $estrutura->getEstrutura()->getHistorico()->getCdcnpjestrut());

                if (!empty($nrCei)) {
                    $this->_nrInscricao = $nrCei;
                    $this->_nrTpInscricao = RegistroSEFIP::CEI;
                } else {
                    $this->_nrInscricao = $nrCnpj;
                    $this->_nrTpInscricao = RegistroSEFIP::CNPJ;
                }

//                if ($tpInscHierarq === RegistroSEFIP::CNPJ) {
//                    $this->_nrInscricao = preg_replace(
//                        self::ALFANUMERICOS,
//                        '',
//                        $estrutura->getEstrutura()->getHistorico()->getCdcnpjestrut()
//                    );
//                    $this->_nrTpInscricao = RegistroSEFIP::CNPJ;
//                } elseif ($tpInscHierarq === RegistroSEFIP::CEI) {
//                    $this->_nrInscricao = preg_replace(
//                        self::ALFANUMERICOS, '',
//                        $estrutura->getEstrutura()->getHistorico()->getCdceiestrut()
//                    );
//                    $this->_nrTpInscricao = RegistroSEFIP::CEI;
//                }

                $this->_preparaRegistro10($estrutura->getEstrutura(), $vinculo->getNrvinculom());

                $this->_preparaRegistro12($estrutura->getEstrutura());

                $ocupacao = $this->_ocupacao->retornaOcupacao($vinculo->historico->getNrcargo());
                if ($this->_dadoVinculo[RegistroSEFIP::SEFIP_REM_SEM_13SAL]
                    || $this->_dadoVinculo[RegistroSEFIP::SEFIP_13SAL_PAGO_MES]) {
                    if ($tpInscHierarqTom) {
                        $movimentacaoGeren = Gpemovimentacao::getMovimentacao(
                            $this->_nrOrg, \FPA::getTipoEstruturaGerencialOrg(), $vinculo->getNrvinculom()
                        );
                        if ($movimentacaoGeren) {

                            if ($movimentacaoGeren->getEstrutura()) {

                                $estruturaTomador = $movimentacaoGeren->getEstrutura()->getEstruturaSuperior($nrTipoHierarquiaTomador);
                                if ($estruturaTomador) {

    //@todo - necessario, pois estava gerando registro 20 sem ninguém.

                                    $pessoa = $this->_pessoa->retornaPessoaAtual($vinculo->getNrpessoa());
                                    $nrPisPasepCi = $pessoa->historico->getNrpispaseppes();
                                    if (!$nrPisPasepCi) {
                                        tk_warning('Pessoa ' . $pessoa->historico->getNmpessoa() . ' não possui PIS/PASEP.');
                                    } else {
                                        $this->_preparaRegistro20($estruturaTomador, $tpInscHierarqTom, $vinculo->getNrvinculom());
                                        $this->_preparaRegistro30($movimentacaoGeren->getEstrutura()->getNrtipoestrutura(), $vinculo, $ocupacao, $estruturaTomador);
                                    }

                                } else {
                                    $this->_preparaRegistro20($estrutura->getEstrutura(), $tpInscHierarqTom, $vinculo->getNrvinculom());
                                    $this->_preparaRegistro30($movimentacaoGeren->getEstrutura()->getNrtipoestrutura(), $vinculo, $ocupacao, $estruturaTomador);
                                }

                            } else {
                                tk_warning('Movimentação do vínculo ' . $vinculo->getNmvinculom() . ' não possui estrutura.');
                            }

                        }
                    } else {
    //                        senao, gera o registro 30 com a estrutura do responsavel
                        $this->_preparaRegistro30($estrutura->getNrtipoestrutura(), $vinculo, $ocupacao, $estrutura, null);
                    }

                    $this->_preparaRegistro32($vinculo, $estrutura, $estruturaTomador);

                } else {
                    tk_warning('Vínculo ' . $vinculo->getNrvinculom() . ' não possui FGTS calculado.');
                }
            }
        } else {
            tk_warning('Estrutura nao encontrada, com data de vigencia maior do que a data de competencia ou nao definido em competencia ou nao definido em hierarquia para o vinculo' . $vinculo->getNrvinculom());
        }
    }

    /* Prepara para a geracao do Registro 10.
     * @param array                $hierarquias    Lista de Hierarquias.
     * @param string               $tpInscHierarq  Tipo de Inscricao da Hierarquia.
     * @param TipohierarqorgEntity $tipoHierarquia Instancia de TipohierarqorgEntity.
     * @param integer              $nrEstruturaMov Numero da estrutura.
     * @return void
     * @author alessandrobartels - 05/01/2012
     */

    private function _preparaRegistro10($estrutura, $nrVinculo)
    {
        $posicao = $this->_gfipMagnetico->procuraRegistroLista(
            $this->_nrInscricao, "0", Registro10SEFIP::REGISTRO_10
        );

        if ($posicao === false) {
            $endereco = $this->_estruturacao->determinaEnderecoEstrutura($estrutura);
            $this->_registro10->setTpInscricao($this->_nrTpInscricao);
            $this->_registro10->setNrInscricao($this->_nrInscricao);
//            monta a linha registro 10.
            $this->_registro10->geraRegistro10($estrutura, $endereco);
//            insere novo registro tipo 10 (base). Os campos nulos sao referentes ao tomador.
            $this->_gfipMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_mesCompetencia, Registro10SEFIP::REGISTRO_10, $this->_nrTpInscricao,
                $this->_nrInscricao, $this->_registro10->getLinhaRegistro()
            );
//            limpa o registro 10.
            $this->_registro10->setLinhaRegistro();
        }
        $this->_consolidaDadosSEFIP(Registro10SEFIP::REGISTRO_10, $this->_nrInscricao, 0);
    }

    /* Prepara para a geracao do Registro 10.
     * @param array                $hierarquias    Lista de Hierarquias.
     * @param string               $tpInscHierarq  Tipo de Inscricao da Hierarquia.
     * @param TipohierarqorgEntity $tipoHierarquia Instancia de TipohierarqorgEntity.
     * @param integer              $nrEstruturaMov Numero da estrutura.
     * @return void
     * @author alessandrobartels - 05/01/2012
     */

    private function _preparaRegistro12($estrutura)
    {
        $posicao = $this->_gfipMagnetico->procuraRegistroLista(
            $this->_nrInscricao, "0", Registro12SEFIP::REGISTRO_12
        );

        if ($posicao === false) {
            $vinculoResp = $this->_vinculom->retornaVinculosPorPessoa($this->_nrOrg, $this->_nrPessoaResp);

            $this->_registro12->setTpInscricao($this->_nrTpInscricao);
            $this->_registro12->setNrInscricao($this->_nrInscricao);
//            carrega o valor de compensação do vínculo do responsável
            foreach ($vinculoResp as $vinculo) {
                $this->_calculaBasesSEFIP($vinculo->getNrvinculom(), true);
            }
//            monta a linha registro 12.
            $this->_registro12->geraRegistro12($estrutura, $this->_dadoVinculo);
//            insere novo registro tipo 12 (base). Os campos nulos sao referentes ao tomador.
            $this->_gfipMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_mesCompetencia, Registro12SEFIP::REGISTRO_12, $this->_nrTpInscricao,
                $this->_nrInscricao, $this->_registro12->getLinhaRegistro()
            );
//            limpa o registro 12.
            $this->_registro12->setLinhaRegistro();
        }
        $this->_consolidaDadosSEFIP(Registro12SEFIP::REGISTRO_12, $this->_nrInscricao, 0);
    }

    /* Prepara para a geracao do Registro 20.
     * @param array                $hierarquias    Lista de Hierarquias.
     * @param string               $tpInscHierarq  Tipo de Inscricao da Hierarquia.
     * @param TipohierarqorgEntity $tipoHierarquia Instancia de TipohierarqorgEntity.
     * @param integer              $nrEstruturaMov Numero da estrutura.
     * @return boolean
     * @author alessandrobartels - 05/01/2012
     */

    private function _preparaRegistro20($estrutura, $tpInscHierarq, $nrVinculo)
    {

//        determina Estrutura Superior - Se autohierarquia  a estrutura eh ela mesma.
        if ($estrutura !== null) {

            // LEONARDOCARVALHO - 23/02/2015 - PRIORIZA O NÚMERO DO CEI, CASO NÃO POSSUA SETA O NUMERO DO CNPJ
            $nrCeiTomador  = preg_replace(self::ALFANUMERICOS, '', $estrutura->getHistorico()->getCdceiestrut());
            $nrCnpjTomador = preg_replace(self::ALFANUMERICOS, '', $estrutura->getHistorico()->getCdcnpjestrut());

            if (!empty($nrCeiTomador)) {
                $this->_nrInscricaoTomador = $nrCeiTomador;
                $this->_nrTpInscricaoTomador = RegistroSEFIP::CEI;
            } else {
                $this->_nrInscricaoTomador = $nrCnpjTomador;
                $this->_nrTpInscricaoTomador = RegistroSEFIP::CNPJ;
            }

//            if ($tpInscHierarq === RegistroSEFIP::CNPJ) {
//                $nrInscricaoTomadorReplace = preg_replace(self::ALFANUMERICOS, '', $estrutura->getHistorico()->getCdcnpjestrut());
//                $this->_nrInscricaoTomador = $nrInscricaoTomadorReplace;
//                $this->_nrTpInscricaoTomador = RegistroSEFIP::CNPJ;
//            } elseif ($tpInscHierarq === RegistroSEFIP::CEI) {
//                $nrInscricaoTomadorReplace = preg_replace(self::ALFANUMERICOS, '', $estrutura->getHistorico()->getCdceiestrut());
//                $this->_nrInscricaoTomador = $nrInscricaoTomadorReplace;
//                $this->_nrTpInscricaoTomador = RegistroSEFIP::CEI;
//            }

            $posicao = $this->_gfipMagnetico->procuraRegistroLista(
                $this->_nrInscricao, $this->_nrInscricaoTomador, Registro20SEFIP::REGISTRO_20, $estrutura->getHistorico()->getNmrazsocestrut()
            );

            if ($posicao === false) {
                $endereco = $this->_estruturacao->determinaEnderecoEstrutura($estrutura);
                $this->_registro20->setTpInscricao($this->_nrTpInscricao);
                $this->_registro20->setNrInscricao($this->_nrInscricao);
                $this->_registro20->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
                $this->_registro20->setNrInscricaoTomador($this->_nrInscricaoTomador);
//                monta a linha registro 20.
                $this->_registro20->geraRegistro20($estrutura, $endereco);
//                insere novo registro tipo 20 (base).
                $this->_gfipMagnetico->insereRegistroLista(
                    $this->_nrOrg, $this->_mesCompetencia, Registro20SEFIP::REGISTRO_20, $this->_nrTpInscricao,
                    $this->_nrInscricao, $this->_registro20->getLinhaRegistro(), $this->_nrTpInscricaoTomador,
                    $this->_nrInscricaoTomador, null, null, '0', null, null, null, $estrutura->getHistorico()->getNmrazsocestrut()
                );
//                limpa o registro 20.
                $this->_registro20->setLinhaRegistro();
            }

            $this->_consolidaDadosSEFIP(Registro20SEFIP::REGISTRO_20, $this->_nrInscricao, $this->_nrInscricaoTomador);
            return true;
        } else {
            return false;
        }
    }

    /* Prepara para a geracao do Registro 30.
     * @param GpevinculomEntity     $vinculo      Instancia de GpevinculomEntity.
     * @param GpemovimentacaoEntity $movimentacao Instancia de GpemovimentacaoEntity.
     * @param GpeOcupacaomEntity    $ocupacao     Instancia de GpeOcupacaomEntity.
     * @param EstruturamEntity      $estrutura    Instancia de EstruturamEntity.
     * @return void
     * @author alessandrobartels - 05/01/2012
     *         alessandrobartels - 20/04/2012 - Implementacao de codigo de Ocorrencia.
     */

    private function _preparaRegistro30($tipoEstrutura, GpevinculomEntity $vinculo, $ocupacao, EstruturamEntity $estrutura)
    {

//        determina ocorrencia.
        if ($vinculo->historico->getIdmultvinc() !== GpevinculohEntity::IDMULTVINC_UNICO) {
            $this->_estruturacao->determinaAreaRisco($vinculo, $estrutura);
            $areaRisco = $this->_estruturacao->getAreaRisco();
            if ($vinculo->historico->getIdmultvinc() === GpevinculohEntity::IDMULTVINC_PRIMARIO) {
                $vinculo->ocorrencia = $areaRisco->getCdocorfgtsunico();
            } elseif ($vinculo->historico->getIdmultvinc() === GpevinculohEntity::IDMULTVINC_SECUNDARIO) {
                $vinculo->ocorrencia = $areaRisco->getCdocorfgtsmult();
            }
        } else {
            $vinculo->ocorrencia = null;
        }

//        @todo Verificar codigo CBO.
        if (is_object($ocupacao) === true) {
            if (is_object($ocupacao->historico) === true) {
				$cbo = $this->_cbo->retornaCbo($ocupacao->historico->getNrcbo());
				if ($cbo) {
					$vinculo->cbo = $cbo->getCdrais();
				} else {
					$vinculo->cbo = null;
					tk_warning('Vínculo ' . $vinculo->getNrvinculom() . ' não possui CBO.');
				}
			} else {
				$vinculo->cbo = null;
				tk_warning('Vínculo ' . $vinculo->getNrvinculom() . ' não possui CBO.');
			}
        } else {
			$vinculo->cbo = null;
            tk_warning('Nao parametrizado ocupação para o vinculo ' . $vinculo->getNrvinculom());
        }

//        verifica Categoria Trabalhador em situação funcional, se não encontrar pega no vinculoempreg.        
        $situacaoFuncional = $this->_sitFuncional->retornaSituacaoFuncional(
            $this->_nrOrgPadrao, $this->_nrOrg, $vinculo->historico->getNrsitufuncm()
        );

		if ($situacaoFuncional) {
			$this->_nrCategoriaTrabalhador = $situacaoFuncional->historico->getCodcategtrab();
			if (empty($this->_nrCategoriaTrabalhador) === true) {
				$vinculoEmpreg = $this->_vinculoEmpreg->retornaVinculoEmpregaticio($vinculo->getNrvinculoempreg());
				if (is_object($vinculoEmpreg) === true) {
					$this->_nrCategoriaTrabalhador = $vinculoEmpreg->getCodcategtrab();
				}
			}
		} else {
            tk_warning('Situação Funcional não parametrizada para o vínculo ' . $vinculo->getNrvinculom());		
		}	

//        loop nas movimentacoes
//        $movimentacoes = $this->_estruturacao->getMovimentacoesVinculo($vinculo->getNrvinculom());

        $pessoa = $this->_pessoa->retornaPessoaAtual($vinculo->getNrpessoa());
        $nrModalidade = $vinculo->historico->getNrtpmodalidsal();
//        pegar na situacao funcional Codfgts e CodfgtsRet
        $this->_registro30->setNrInscricao($this->_nrInscricao);
        $this->_registro30->setNrInscricaoTomador($this->_nrInscricaoTomador);
        $this->_registro30->setTpInscricao($this->_nrTpInscricao);
        $this->_registro30->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
        $this->_registro30->setCodMovimentacao($this->_codMovimentacao);
        $this->_registro30->setNrCategoria($this->_nrCategoriaTrabalhador);
//        pisPasep.
        $nrPisPasepCi = $pessoa->historico->getNrpispaseppes();
        if (!$nrPisPasepCi) {
            tk_warning('Vínculo ' . $vinculo->getNmvinculom() . ' sem PIS/PASEP/CI.');
        } else {

//            registro 30.
            $this->_registro30->geraRegistro30($pessoa, $vinculo, $this->_dadoVinculo);
            $vrSalarioFamilia = Valor::arredonda($this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_FAMILIA], Valor::TOTAL, -2, 5);
            $vrSalarioMaternidade = Valor::arredonda($this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE], Valor::TOTAL, -2, 5);

//            persiste registro linha 30.
            $this->_gfipMagnetico->persisteRegistro(
                $this->_nrOrg, $this->_mesCompetencia, Registro30SEFIP::REGISTRO_30, $this->_nrTpInscricao,
                $this->_nrInscricao, $this->_nrTpInscricaoTomador, $this->_nrInscricaoTomador,
                $this->_registro30->getLinhaRegistro(), $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(),
                $nrPisPasepCi, $vrSalarioFamilia, $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador
            );
//            limpa o registro 30.
            $this->_registro30->setLinhaRegistro();
        }
    }

    /* Enter description here ...
     * @param GpevinculomEntity     $vinculo                Instancia de GpevinculomEntity.
     * @param GpemovimentacaoEntity $movimentacao           Instancia de GpemovimentacaoEntity.
     * @param string                $this->_nrCategoriaTrabalhador Categoria do Trabalhador.
     * @return void
     */

    private function _preparaRegistro32(GpevinculomEntity $vinculo, GpemovimentacaoEntity $gpemovimentacao, EstruturamEntity $estrutura)
    {

        $pessoa = $this->_pessoa->retornaPessoaAtual($vinculo->getNrpessoa());
        $nrPisPasepCi = $pessoa->historico->getNrpispaseppes();
//        verifica data de rescisao do vinculo.
        $dataRescisao = $vinculo->getDtrescisaovinc();

        // LEONARDOCARVALHO 17/09/2014
        if (empty($dataRescisao) === false) {
            $dataRescisao = new \TkDateTime($vinculo->getDtrescisaovinc());
        }

//        RESCISAO - gera registro 32 quando rescisao ocorreu anterior ao mes de competencia e tiver rescisao
//        complementar ou atrasada. Busca no vinculo a data e o tipo de rescisao. No tipo, consta o cod FGTS.

        // LEONARDOCARVALHO 17/09/2014 - ALTERADA CONDIÇÃO PARA 'isBetween', pois a rescisão não entrava no SEFIP
        if (empty($dataRescisao) === false
            && ($dataRescisao->isBetween($this->_dtInicio, \FPA::getUltimoDiaMes()))
        ) {
//            @todo Verificar se o teste da data de competencia compreende o mes inteiro (1 a 31), ou seja, se tem que .
//            rescisao complementar ou atrasada. Verificar se possui item calculo.
            $objTpDemissao = $this->_tpDemissao->procuraTipoDemissao($vinculo->getNrtpdemissao());
            if (!$objTpDemissao) {
                tk_warning('Vínculo '.$vinculo->getNrvinculom().' não possui tipo de demissão informado.');
            } else {
                $codFGTS = $objTpDemissao->getCodfgts();
            }
            $this->_registro32->setNrInscricao($this->_nrInscricao);
            $this->_registro32->setNrInscricaoTomador($this->_nrInscricaoTomador);
            $this->_registro32->setTpInscricao($this->_nrTpInscricao);
            $this->_registro32->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
            $this->_registro32->setNrCategoria($this->_nrCategoriaTrabalhador);
            $this->_registro32->setCodMovimentacao($codFGTS);
            $this->_registro32->setDtMovimentacao($dataRescisao);
            $this->_registro32->geraRegistro32($pessoa, $vinculo, $this->_mesCompetencia);
            $vrSalarioFamilia = Valor::arredonda($this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_FAMILIA], Valor::TOTAL, -2, 5);
            $vrSalarioMaternidade = Valor::arredonda($this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE], Valor::TOTAL, -2, 5);
            $this->_gfipMagnetico->insereRegistroLista(
                $this->_nrOrg, $this->_mesCompetencia, Registro32SEFIP::REGISTRO_32, $this->_nrTpInscricao,
                $this->_nrInscricao, $this->_registro32->getLinhaRegistro(), $this->_nrTpInscricaoTomador,
                $this->_nrInscricaoTomador, $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(),
                $nrPisPasepCi, $vrSalarioFamilia, $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador
            );
//            limpa o registro 32.
            $this->_registro32->setLinhaRegistro();
        }

//        AFASTAMENTO - Verifica o periodo de afastamento do vinculo. Se data fim for maior que o final do periodo ou
//        nao existir, gera o Registro 32 com o codigo do afastamento. Se data fim tiver dentro do periodo, gera o
//        Registro 32 com o codigo do afastamento e Registro 32 com codigo do retorno.

        $alteracoes = $this->_altSitFuncional->retornaAlteSituFuncporVinculo($vinculo->getNrvinculom(), $this->_nrOrg);
        /** @var $item GpealtesitufuncEntity */
        foreach ($alteracoes as $item) {

            // LEONARDOCARVALHO 16/09/2014 - CRIADA CONDIÇÃO PARA NÃO GERAR REGISTRO QUANDO SITUAÇÃO FUNCIONAL FOR DE DEMITIDO
            if ($item->getNrsitufuncm() != GpealtesitufuncEntity::SIT_FUNC_DEMITIDO) {

                $gerouMovimento = false;
                //            Gera Movimentacao. Data fim posterior ah data inicial ou inexistente.
                $dtFim = $item->getDtfimsitufunc();
                $dtIni = $item->getDtinisitufunc();
                $iniSituaFunc = new TkDateTime($dtIni);

                //            se a data final estiver vazio e a data final da competência for
                if ((empty($dtFim) === true) || ($this->_dtFim->isLater($dtIni) === true)) {
                    $testa_inicio = false;
                    if (empty($dtFim)) {
                        if ($iniSituaFunc->isLater($this->_dtFim)) {
                            $testa_inicio = false;
                        } else {
                            $testa_inicio = true;
                        }
                    } else {
                        if ($this->_dtInicio->isLater($dtFim) !== true) {
                            $testa_inicio = true;
                        }
                    }
                    if ($testa_inicio) {

                        //                    @todo - verificar melhor esta regra / verifica se a situacao funcional é diferente de 'atividade normal'
                        if ($item->getNrsitufuncm() != GpealtesitufuncEntity::SIT_FUNC_NORMAL) {
                            $situacaoFuncional = $this->_sitFuncional->retornaSituacaoFuncional($this->_nrOrgPadrao,
                                $this->_nrOrg, $item->getNrsitufuncm());
                            $codFGTS = $situacaoFuncional->historico->getCodfgts();
                            if (empty($codFGTS) !== true) {

                                $dtinicial = $iniSituaFunc->subDay(1);
                                $this->_registro32->setNrInscricao($this->_nrInscricao);
                                $this->_registro32->setNrInscricaoTomador($this->_nrInscricaoTomador);
                                $this->_registro32->setTpInscricao($this->_nrTpInscricao);
                                $this->_registro32->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
                                $this->_registro32->setNrCategoria($this->_nrCategoriaTrabalhador);
                                $this->_registro32->setCodMovimentacao($codFGTS);
                                $this->_registro32->setDtMovimentacao($dtinicial);
                                $this->_registro32->geraRegistro32($pessoa, $vinculo, $this->_mesCompetencia);
                                $this->_gfipMagnetico->insereRegistroLista(
                                    $this->_nrOrg, $this->_mesCompetencia, Registro32SEFIP::REGISTRO_32, $this->_nrTpInscricao,
                                    $this->_nrInscricao, $this->_registro32->getLinhaRegistro(), $this->_nrTpInscricaoTomador,
                                    $this->_nrInscricaoTomador, $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(),
                                    $nrPisPasepCi, $vrSalarioFamilia, $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador
                                );
                                //                        limpa o registro 32.
                                $this->_registro32->setLinhaRegistro();
                                $gerouMovimento = true;
                                //                        @todo -> No ARTE faz tratamento para Q2 (complemento de licenca maternidade);
                                //                        Faz tratamento para gerar base de INSS no Registro 30 (conforme cod movimentacao).
                            } else {
                                tk_warning('Codigo de FGTS nao parametrizado na situacao funcional para o vinculo '
                                    . $vinculo->getNrvinculom());
                            }
                        }
                    }
                }

                $dtFim = new \TkDateTime($dtFim);

                //            gera retorno. Data fim dentro do intervalo (Para gerar o retorno deve ter gerado a movimentacao acima).
                if (empty($dtFim) === false) {
                    if (($gerouMovimento === true)
                        && ($dtFim->isBetween($this->_dtInicio, \FPA::getUltimoDiaMes())))
                    {
                        $codFGTS = $situacaoFuncional->historico->getCodfgtsret();
                        if (empty($codFGTS) !== true) {
                            $this->_registro32->setNrInscricao($this->_nrInscricao);
                            $this->_registro32->setNrInscricaoTomador($this->_nrInscricaoTomador);
                            $this->_registro32->setTpInscricao($this->_nrTpInscricao);
                            $this->_registro32->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
                            $this->_registro32->setNrCategoria($this->_nrCategoriaTrabalhador);
                            $this->_registro32->setCodMovimentacao($codFGTS);
                            $this->_registro32->setDtMovimentacao($dtFim);
                            $this->_registro32->geraRegistro32($pessoa, $vinculo, $this->_mesCompetencia);
                            $this->_gfipMagnetico->insereRegistroLista(
                                $this->_nrOrg, $this->_mesCompetencia, Registro32SEFIP::REGISTRO_32, $this->_nrTpInscricao,
                                $this->_nrInscricao, $this->_registro32->getLinhaRegistro(), $this->_nrTpInscricaoTomador,
                                $this->_nrInscricaoTomador, $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(),
                                $nrPisPasepCi, $vrSalarioFamilia, $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador
                            );
                            //                        limpa o registro 32.
                            $this->_registro32->setLinhaRegistro();
                            //                        @todo -> No ARTE faz tratamento para Q2 (complemento de licenca maternidade);
                            //                        Faz tratamento para gerar base de INSS no Registro 30 (conforme cod movimentacao).
                            //                        procura o cdoFGTSRet na situacao funcional;
                            //                        gerar Registro 32  com a data de fim de afastamento;
                        }
                    }
                }
            }
        }

        // LEONARDOCARVALHO 16/09/2014 - ALTERADA CONDIÇÃO PARA NÃO GERAR REGISTRO DO TIPO DE SITUAÇÃO FUNCIONAL DE DEMITIDO
       if ($item->getNrsitufuncm() != GpealtesitufuncEntity::SIT_FUNC_NORMAL
           || $item->getNrsitufuncm() != GpealtesitufuncEntity::SIT_FUNC_DEMITIDO) {
           //        MOVIMENTACAO - Verifica o codigo da movimentacao FGTS em GPE_TPMOVTRANSFH atraves do tipo de movimentacao.
           /** @var $situfuncm GpesitufuncmEntity */
           $situfuncm = GpesitufuncmEntity::getEntityByWhere(
               'NRORG = ? AND NRSITUFUNCM = ?',
               array($this->_nrOrg, $item->getNrsitufuncm())
           );
           if (is_object($situfuncm) === true) {

               $codFGTS = $situfuncm->getHistorico()->getCodfgts();

               if (empty($codFGTS) !== true) {
                   $this->_registro32->setNrInscricao($this->_nrInscricao);
                   $this->_registro32->setNrInscricaoTomador($this->_nrInscricaoTomador);
                   $this->_registro32->setTpInscricao($this->_nrTpInscricao);
                   $this->_registro32->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
                   $this->_registro32->setNrCategoria($this->_nrCategoriaTrabalhador);
                   $this->_registro32->setCodMovimentacao($codFGTS);
                   $this->_registro32->setDtMovimentacao($item->getDtinisitufunc());
                   $this->_registro32->geraRegistro32($pessoa, $vinculo, $this->_mesCompetencia);
                   $this->_gfipMagnetico->insereRegistroLista($this->_nrOrg, $this->_mesCompetencia,
                       Registro32SEFIP::REGISTRO_32, $this->_nrTpInscricao, $this->_nrInscricao,
                       $this->_registro32->getLinhaRegistro(), $this->_nrTpInscricaoTomador, $this->_nrInscricaoTomador,
                       $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(), $nrPisPasepCi, $vrSalarioFamilia,
                       $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador);
                   //                limpa o registro 32.
                   $this->_registro32->setLinhaRegistro();
               }
           }
       }
       $this->_codMovimentacao = $codFGTS;

        // LEONARDOCARVALHO 16/09/2014 - ARRAY COM OS NÚMEROS DOS TIPOS DE MOVIMENTO DE TRANSFERÊNCIA
        $tranferenciaDemissao = array('8','9');

        // gera um arquivo 32 para movimentacao ( transferencia ) no mes da competencia.
        $inicioMovimentacao = New TkDateTime($gpemovimentacao->getDtinimoviment());

        // LEONARDOCARVALHO 16/09/2014 - ALTERADA CONDIÇÃO PARA NÃO GERAR REGISTROS DOS TIPOS DE MOVIMENTO DE DEMISSÃO/DESLIGAMENTO
        if ((array_search($gpemovimentacao->getNrtpmovtransfm(), $tranferenciaDemissao) !== false) &&
            (($inicioMovimentacao->isLater($this->_dtInicio)) ||
                ($inicioMovimentacao->equals($this->_dtInicio)) &&
                ($gpemovimentacao->getNrtpmovtransfm() == self::TRANSFERENCIA_ENTRADA) ||
                ($gpemovimentacao->getNrtpmovtransfm() == self::TRANSFERENCIA_SAIDA))
        ) {
            $inicioAdmissao = New TkDateTime($vinculo->getDtadmissaovinc());
            if ($inicioAdmissao->isEarlier($inicioMovimentacao)) {

                // LEONARDOCARVALHO - 04/10/2014 - ALTERADO PARA BUSCAR O CÓDIGO FGTS DO TIPO MOTIVO TRANSFERÊNCIA DA MOVIMENTAÇÃO
                $codMovimentacao = \Folha\Entities\GpeTpmovtransfh::findOneByNrtpmovtransfmAndNrtpmovtransfh($gpemovimentacao->getNrtpmovtransfm(), $gpemovimentacao->getNrtpmovtransfm());

                $this->_registro32->setNrInscricao($this->_nrInscricao);
                $this->_registro32->setNrInscricaoTomador($this->_nrInscricaoTomador);
                $this->_registro32->setTpInscricao($this->_nrTpInscricao);
                $this->_registro32->setTpInscricaoTomador($this->_nrTpInscricaoTomador);
                $this->_registro32->setNrCategoria($this->_nrCategoriaTrabalhador);
                $this->_registro32->setCodMovimentacao($codMovimentacao->getCodfgts());
                $this->_registro32->setDtMovimentacao($gpemovimentacao->getDtinimoviment());
                $this->_registro32->geraRegistro32($pessoa, $vinculo, $this->_mesCompetencia);
                $this->_gfipMagnetico->insereRegistroLista($this->_nrOrg, $this->_mesCompetencia,
                    Registro32SEFIP::REGISTRO_32, $this->_nrTpInscricao, $this->_nrInscricao,
                    $this->_registro32->getLinhaRegistro(), $this->_nrTpInscricaoTomador, $this->_nrInscricaoTomador,
                    $vinculo->getNrvinculom(), $vinculo->getDtadmissaovinc(), $nrPisPasepCi, $vrSalarioFamilia,
                    $vrSalarioMaternidade, $this->_nrCategoriaTrabalhador);
                $this->_registro32->setLinhaRegistro();

            }
        }

    }

    /* Enter description here ...
     * @param EstruturamEntity $estrutura Instancia de EstruturamEntity.
     * @return EnderecoEntity
     * @author alessandrobartels - 03/01/2012
     */

    private function _calculaBasesSEFIP($nrVinculo, $idResponsavel = false)
    {
//        carregar todos os itens de calculo.
        // LEONARDOCARVALHO - 02/10/2014 - Não estava somando o 13º Salário por limpar o array a cada iteração
        if ($idResponsavel) {
            foreach ($this->_listaCalculoFolha as $nrCalculo) {
                $contador = $this->_itemCalculo->retornaItensPorVinculo($this->_nrOrg, $nrVinculo, $nrCalculo);
                $this->_calculaCompensacao();
                $this->_calculaValorCooperativas();
            }
        }
        else {
            $this->_dadoVinculo = array();
            foreach ($this->_listaCalculoFolha as $nrCalculo) {
                $contador = $this->_itemCalculo->retornaItensPorVinculo($this->_nrOrg, $nrVinculo, $nrCalculo);
                $this->_calculaSalarioFamilia();
                $this->_calculaSalarioMaternidade();
                $this->_calculaRemuneracaoSem13Salario();
                $this->_calculaRemuneracao13SalarioMensal();
                $this->_calculaRemuneracaoContribuicaoPrevidenciaria();
                $this->_calculaRemuneracao13SalarioCompetenciaMovimento();
                $this->_calculaRemuneracao13SalarioGPSCompetencia13();
                $this->_calculaInssMultiplosVinculos();
            }
        }
    }

    private function _calculaValorItemGrupo($referencia)
    {
        $valor = $this->_itemGrupo->calculaValorItemGrupoIncidencia(
            $this->_mesCompetencia, $this->_itemCalculo, $this->_evento, $referencia
        );
        return $valor;
    }

    private function _calculaSalarioFamilia()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_SALARIO_FAMILIA);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_SALARIO_FAMILIA, $valor);
    }

    private function _calculaSalarioMaternidade()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE, $valor);
    }

    private function _calculaRemuneracaoSem13Salario()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_REM_SEM_13SAL);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_REM_SEM_13SAL, $valor);
    }

    private function _calculaRemuneracao13SalarioMensal()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_13SAL_PAGO_MES);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_13SAL_PAGO_MES, $valor);
    }

    private function _calculaRemuneracaoContribuicaoPrevidenciaria()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_REM_BASE_GPS);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_REM_BASE_GPS, $valor);
    }

    private function _calculaRemuneracao13SalarioCompetenciaMovimento()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_REM_13SAL_MOV);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_REM_13SAL_MOV, $valor);
    }

    private function _calculaRemuneracao13SalarioGPSCompetencia13()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_REM_13SAL_GPS);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_REM_13SAL_GPS, $valor);
    }

    private function _calculaInssMultiplosVinculos()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_INSS_MULT_VINCULOS);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_INSS_MULT_VINCULOS, $valor);
    }

    private function _calculaCompensacao()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_COMPEN_VLRCORR);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_COMPEN_VLRCORR, $valor);
    }

    private function _calculaValorCooperativas()
    {
        $valor = $this->_calculaValorItemGrupo(RegistroSEFIP::SEFIP_VALOR_NF_COOPER);
        $this->_consolidaDadosVinculo(RegistroSEFIP::SEFIP_VALOR_NF_COOPER, $valor);
    }

//    @todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
//    private function _pesquisaSalarioMaternidadeFamilia($tipoAssociacao) {
//       /* $evento = $this->_assocEvento->retornaEventoAssociado($tipoAssociacao, $this->_evento, $this->_nrOrg);
//        $posicao = end($this->_itemCalculo->retornaItens($evento));
//        if ($posicao !== false) {
//            $valor = $this->_itemCalculo->retornaValor($posicao);
//        } else {
//            $valor = 0;
//        }
//
//        return $valor;
//       */
//    }

    private function _consolidaDadosVinculo($referencia, $valor)
    {
        $this->_dadoVinculo[$referencia] += $valor;
    }

    private function _consolidaDadosSEFIP($tpRegistro, $nrInscricao, $nrInscricaoTomador)
    {
        $posicao = $tpRegistro . '.' . $nrInscricao . '.' . $nrInscricaoTomador;
        if ($tpRegistro === Registro10SEFIP::REGISTRO_10) {
            $this->_consolidaDados(
                $posicao, RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE, $this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_MATERNIDADE]
            );
        }
        $this->_consolidaDados(
            $posicao, RegistroSEFIP::SEFIP_SALARIO_FAMILIA, $this->_dadoVinculo[RegistroSEFIP::SEFIP_SALARIO_FAMILIA]
        );
    }

//    @todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
    private function _consolidaDados($posicao, $referencia, $valor)
    {
        $this->_dadoAlterado[$posicao][$referencia] += $valor;
    }

//    @todo - caso haja necessidade de modificar outros registros, modificar o nome do metodos para um mais generico.
    public function modificaSalarioMaternidadeFamilia()
    {
//        modificar
        foreach ($this->_dadoAlterado as $posicao => $valor) {
//            testa a posicao diferente de 0, pois ao ser declarado o vetor cria esta posicao e a mesma nao eh utilizada.
            if ($posicao !== 0) {
                list($tpRegistro, $nrInscricao, $nrInscricaoTom) = explode('.', $posicao);
                $posRegistro = $this->_gfipMagnetico->procuraRegistroLista($nrInscricao, $nrInscricaoTom, $tpRegistro);
                $registroMag = $this->_gfipMagnetico->getItem($posRegistro);
//                criar metodo generico no FPA Registro para fazer modificacao da linha
                if ($tpRegistro === Registro10SEFIP::REGISTRO_10) {
                    $this->_registro10->alteraDadoRegistro10($registroMag, $valor);
                } elseif ($tpRegistro === Registro20SEFIP::REGISTRO_20) {
                    $this->_registro20->alteraDadoRegistro20($registroMag, $valor);
                }
            }
        }
    }

    /* Retrocede os registros da Org. no mes de competencia.
     * @return void
     * @author alessandrobartels - 04/01/2012
     */

    public function retroceder()
    {
        $this->_gfipMagnetico->retroceder($this->_nrOrg, $this->_mesCompetencia);
    }

	
	
	
}