/******************************************************************************/
/* AGENT2B                                                                    */
/*                                                                            */
/* Compras e Suprimentos                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome:                                                                      */
/*                                                                            */
/* Descrio:                                                                 */
/*    Faz o fechamento de uma AF                                              */
/*                                                                            */
/* Criao:                                                                   */
/*   07/07/2003 - Adriano de Arajo                                           */
/*                                                                            */
/******************************************************************************/
/* @C:\Web_V2\Srv\Src\Sup\Fechamento_AF.sql                                   */
/******************************************************************************/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE
            O.NAME = 'FECHAMENTO_AF' AND
            TYPE = 'P'                      AND
            U.UID = O.UID                   AND
            U.NAME = USER)

   DROP PROCEDURE FECHAMENTO_AF;
GO

CREATE PROCEDURE FECHAMENTO_AF
(
   @P_CDFILDEST  VARCHAR(4),
   @P_CDFILLANC  VARCHAR(4),
   @P_NRAUTOFORN VARCHAR(10)
)
AS

DECLARE @V_CDFORNECED  VARCHAR(21);
DECLARE @V_DTPROGENTAF DATETIME;
DECLARE @V_CDEMPRESA   VARCHAR(2);
DECLARE @V_VRIMPOSTO   NUMERIC(15,5);
DECLARE @V_VRENCAFPOS  NUMERIC(15,5);
DECLARE @V_VRENCAFNEG  NUMERIC(15,5);
DECLARE @V_CDOPERADOR  VARCHAR(12);
DECLARE @V_CDINSCESTA  VARCHAR(21);
DECLARE @V_VRPRODUTO   NUMERIC(15,5);
DECLARE @V_CDPRODESTO  VARCHAR(10);
DECLARE @V_VRDESCONTO  NUMERIC(15,5);

DECLARE @V_PRECMEDIO_CDFILDEST   VARCHAR(4);
DECLARE @V_PRECMEDIO_DTAUTOFORN  DATETIME;
DECLARE @V_PRECMEDIO_CDPRODESTO  VARCHAR(10);
DECLARE @V_PRECMEDIO_CDTIPOCUSTO VARCHAR(2);
DECLARE @V_PRECMEDIO_IDMOEDCUSTO VARCHAR(1);
DECLARE @V_PRECMEDIO_VRMEDIO     NUMERIC(15,5);

BEGIN
   /* Dados da AF */
   SELECT
     @V_CDFORNECED = MAX(CDFORNECED),
     @V_CDEMPRESA  = ISNULL(MAX(AUTOFORNE.CDEMPRESA), MAX(FILIAL.CDEMPRESA)),
     @V_CDOPERADOR = MAX(CDOPERADOR)
   FROM
     AUTOFORNE,
     FILIAL
   WHERE
     FILIAL.CDFILIAL = @P_CDFILDEST AND
     CDFILDEST       = @P_CDFILDEST AND
     CDFILLANC       = @P_CDFILLANC AND
     NRAUTOFORN      = @P_NRAUTOFORN;

   /* Gerao das Parcelas */
   UPDATE ITEMAUTF
   SET NRPARCITMAF = (SELECT
   							RIGHT (REPLICATE('0',2)+ CONVERT(VARCHAR,COUNT(DISTINCT ITEM.DTPROGENTAF)),2)
                      FROM
                        ITEMAUTF ITEM
                      WHERE
                        ITEM.CDFILDEST   = @P_CDFILDEST  AND
                        ITEM.CDFILLANC   = @P_CDFILLANC  AND
                        ITEM.NRAUTOFORN  = @P_NRAUTOFORN AND
                        ITEM.DTPROGENTAF <= ITEMAUTF.DTPROGENTAF)
   WHERE
      CDFILDEST  = @P_CDFILDEST AND
      CDFILLANC  = @P_CDFILLANC AND
      NRAUTOFORN = @P_NRAUTOFORN;

   SET @V_CDINSCESTA = NULL;
   SELECT
     @V_CDINSCESTA = MIN(CDINSCESTA)
   FROM
     FILIAL
   WHERE
     CDFILIAL  = @P_CDFILDEST AND
     CDEMPRESA = @V_CDEMPRESA;

   IF @V_CDINSCESTA IS NULL BEGIN
      SELECT
        @V_CDINSCESTA = MIN(CDINSCESTA)
      FROM
        EMPRCNTRFIL
      WHERE
        CDEMPRESA = @V_CDEMPRESA;
   END;

   IF @V_CDINSCESTA IS NULL BEGIN
      SELECT
        @V_CDINSCESTA = MIN(CDINSCESTA)
      FROM
        INSCRESTAD
      WHERE
        CDEMPRESA = @V_CDEMPRESA;
   END;

   SELECT
     @V_DTPROGENTAF = MIN(DTPROGENTAF)
   FROM
     ITEMAUTF
   WHERE
     CDFILDEST  = @P_CDFILDEST AND
     CDFILLANC  = @P_CDFILLANC AND
     NRAUTOFORN = @P_NRAUTOFORN;

   EXEC IMPOSTO_ITEMAF @V_CDEMPRESA,
                       @V_CDINSCESTA,
                       @V_CDFORNECED,
                       @P_CDFILDEST,
                       @P_CDFILLANC,
                       @P_NRAUTOFORN,
                       @V_DTPROGENTAF;

   /* Atualizao do Valor Total da AF */
   SELECT
      @V_VRPRODUTO = SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF),
      @V_VRDESCONTO = SUM((ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF * ISNULL(ITEMAUTF.VRPERDESAF, 0)) / 100)
   FROM
      ITEMAUTF
   WHERE
      CDFILDEST  = @P_CDFILDEST AND
      CDFILLANC  = @P_CDFILLANC AND
      NRAUTOFORN = @P_NRAUTOFORN;

   SELECT
     @V_VRIMPOSTO = ISNULL(SUM(IMPITMAF.VRADIMPAF), 0)
   FROM
     IMPITMAF,
     ITEMAUTF
   WHERE
      IMPITMAF.CDFILDEST   = @P_CDFILDEST          AND
      IMPITMAF.CDFILLANC   = @P_CDFILLANC          AND
      IMPITMAF.NRAUTOFORN  = @P_NRAUTOFORN         AND
      IMPITMAF.CDFILDEST   = ITEMAUTF.CDFILDEST   AND
      IMPITMAF.CDFILLANC   = ITEMAUTF.CDFILLANC   AND
      IMPITMAF.NRAUTOFORN  = ITEMAUTF.NRAUTOFORN  AND
      IMPITMAF.CDPRODUTO   = ITEMAUTF.CDPRODUTO   AND
      IMPITMAF.CDMARCA     = ITEMAUTF.CDMARCA     AND
      IMPITMAF.DTPROGENTAF = ITEMAUTF.DTPROGENTAF;

   /* BUSCA A PARTE POSITIVA DO ENCARGO */
   SELECT
     @V_VRENCAFPOS = ISNULL(SUM(ENCARGOAF.VRENCARGOAF), 0)
   FROM
     ENCARGOAF,
     ENCARGO
   WHERE
     ENCARGO.IDENCARGO    = 'A'          AND
     ENCARGOAF.CDFILDEST  = @P_CDFILDEST  AND
     ENCARGOAF.CDFILLANC  = @P_CDFILLANC  AND
     ENCARGOAF.NRAUTOFORN = @P_NRAUTOFORN AND
     ENCARGO.CDENCARGO    = ENCARGOAF.CDENCARGO;

   /* BUSCA A PARTE NEGATIVA DO ENCARGO */
   SELECT
     @V_VRENCAFNEG = ISNULL(SUM(ENCARGOAF.VRENCARGOAF), 0)
   FROM
     ENCARGOAF,
     ENCARGO
   WHERE
     ENCARGO.IDENCARGO    = 'D'          AND
     ENCARGOAF.CDFILDEST  = @P_CDFILDEST  AND
     ENCARGOAF.CDFILLANC  = @P_CDFILLANC  AND
     ENCARGOAF.NRAUTOFORN = @P_NRAUTOFORN AND
     ENCARGO.CDENCARGO    = ENCARGOAF.CDENCARGO;

   UPDATE AUTOFORNE
   SET VRTOTALAF = @V_VRPRODUTO - @V_VRDESCONTO + @V_VRIMPOSTO + @V_VRENCAFPOS - @V_VRENCAFNEG
   WHERE
      CDFILDEST  = @P_CDFILDEST AND
      CDFILLANC  = @P_CDFILLANC AND
      NRAUTOFORN = @P_NRAUTOFORN;


   /* Gravao do Custo da ltima AF*/
   SET @V_CDPRODESTO = '';

   DECLARE C_PRECMEDIO CURSOR FOR
     SELECT
        ITEMAUTF.CDFILDEST,
        AUTOFORNE.DTAUTOFORN,
        PRODUTO.CDPRODESTO,
        TIPOCUSTO.CDTIPOCUSTO,
        TIPOCUSTO.IDMOEDCUSTO,
        AVG(ITEMAUTF.VRPREUNIAF/PRODUTO.VRFATOCONV) AS VRMEDIO
     FROM
        TIPOCUSTO,
        PARAMGERAL,
        PRODUTO,
        AUTOFORNE,
        ITEMAUTF
     WHERE
        ITEMAUTF.CDFILLANC  = @P_CDFILLANC  AND
        ITEMAUTF.CDFILDEST  = @P_CDFILDEST  AND
        ITEMAUTF.NRAUTOFORN = @P_NRAUTOFORN AND
        ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC  AND
        ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST  AND
        ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN AND

        TIPOCUSTO.CDTIPOCUSTO IN ('07', '32', '33') AND

        PRODUTO.CDPRODUTO   = ITEMAUTF.CDPRODUTO
     GROUP BY
        ITEMAUTF.CDFILDEST,
        AUTOFORNE.DTAUTOFORN,
        PRODUTO.CDPRODESTO,
        TIPOCUSTO.CDTIPOCUSTO,
        TIPOCUSTO.IDMOEDCUSTO
     ORDER BY
        ITEMAUTF.CDFILDEST,
        AUTOFORNE.DTAUTOFORN,
        PRODUTO.CDPRODESTO;
   OPEN C_PRECMEDIO;
   FETCH NEXT FROM C_PRECMEDIO INTO @V_PRECMEDIO_CDFILDEST,
                                    @V_PRECMEDIO_DTAUTOFORN,
                                    @V_PRECMEDIO_CDPRODESTO,
                                    @V_PRECMEDIO_CDTIPOCUSTO,
                                    @V_PRECMEDIO_IDMOEDCUSTO,
                                    @V_PRECMEDIO_VRMEDIO;

   WHILE (@@FETCH_STATUS = 0) BEGIN
      IF @V_CDPRODESTO <> @V_PRECMEDIO_CDPRODESTO BEGIN
         UPDATE PRODFILI
         SET DTULTAUTFOR  = @V_PRECMEDIO_DTAUTOFORN,
             VRPRECUAFOFI = @V_PRECMEDIO_VRMEDIO,
             VRPRECUAFOM1 = (SELECT ISNULL(MAX(MOVINDICE.VRINDICE), 0) * ISNULL(@V_PRECMEDIO_VRMEDIO, 0)
                             FROM PARAMGERAL, MOVINDICE
                             WHERE PARAMGERAL.CDINDICEMF = MOVINDICE.CDINDICE AND
                                   MOVINDICE.DTREFIND    = @V_PRECMEDIO_DTAUTOFORN AND
                                   MOVINDICE.CDTPINDICE  = '1' AND
                                   MOVINDICE.IDPERVALOR  = '2'),
             VRPRECUAFOM2 = (SELECT ISNULL(MAX(MOVINDICE.VRINDICE), 0) * ISNULL(@V_PRECMEDIO_VRMEDIO, 0)
                             FROM PARAMGERAL, MOVINDICE
                             WHERE PARAMGERAL.CDINDICEMF2 = MOVINDICE.CDINDICE AND
                                   MOVINDICE.DTREFIND     = @V_PRECMEDIO_DTAUTOFORN AND
                                   MOVINDICE.CDTPINDICE   = '1' AND
                                   MOVINDICE.IDPERVALOR   = '2')
         WHERE
            CDFILIAL  = @P_CDFILDEST AND
            CDPRODUTO = @V_PRECMEDIO_CDPRODESTO;

      END;
      FETCH NEXT FROM C_PRECMEDIO INTO @V_PRECMEDIO_CDFILDEST,
                                       @V_PRECMEDIO_DTAUTOFORN,
                                       @V_PRECMEDIO_CDPRODESTO,
                                       @V_PRECMEDIO_CDTIPOCUSTO,
                                       @V_PRECMEDIO_IDMOEDCUSTO,
                                       @V_PRECMEDIO_VRMEDIO;
   END;
   CLOSE C_PRECMEDIO;
   DEALLOCATE C_PRECMEDIO;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'FECHAMENTO_AF','6.19.000';
GO

